Learn R Programming

CNPS (version 1.0.0)

siegel_tukey: Siegel-Tukey Test

Description

Performs two-sample Siegel-Tukey test on vectors of data.

Usage

siegel_tukey (x,y,adjust.median=FALSE,...)

Arguments

x

numeric vector of data values.

y

numeric vector of data values.

adjust.median

a logical indicating whether you want the adjusted median, which represents difference of each value with median.

...

The input from twosample_test function.

Value

method

the test used.

stat

the statistic of the original data.

conf.int

the confidence interval for p-value(only if method_p = "sampling")

pval

p-value for the test

alternative

a character string describing the alternative hypothesis.

Details

The test is about the scale parameter, to test the deviance. The arguments you want to modify is almost same with twosample_test.

References

Higgins, J. J. (2004). An introduction to modern nonparametric statistics. Pacific Grove, CA: Brooks/Cole.

Examples

Run this code
# NOT RUN {
## A simple example
x <- c(33, 62, 84, 85, 88, 93, 97)
y<-c(4, 16, 48, 51, 66, 98)
siegel_tukey(x,y,adjust.median=FALSE)

# }

Run the code above in your browser using DataLab