powered by
Performs two-sample Siegel-Tukey test on vectors of data.
siegel_tukey (x,y,adjust.median=FALSE,...)
numeric vector of data values.
a logical indicating whether you want the adjusted median, which represents difference of each value with median.
The input from twosample_test function.
the test used.
the statistic of the original data.
the confidence interval for p-value(only if method_p = "sampling")
p-value for the test
a character string describing the alternative hypothesis.
The test is about the scale parameter, to test the deviance. The arguments you want to modify is almost same with twosample_test.
twosample_test
Higgins, J. J. (2004). An introduction to modern nonparametric statistics. Pacific Grove, CA: Brooks/Cole.
# NOT RUN { ## A simple example x <- c(33, 62, 84, 85, 88, 93, 97) y<-c(4, 16, 48, 51, 66, 98) siegel_tukey(x,y,adjust.median=FALSE) # }
Run the code above in your browser using DataLab